# icode123


```python
# 环境检测
import icode123

icode123.check()

```

```text

请输入 Icode123 邮箱：********@sina.com
请输入 Icode123 密码：********

1.2022 秋季小学期
2.ECE实习 Ⅰ（计算机编程 ）2021级本科生大二课程
请输入班级序号：1
正在检查本机已安装 Python 包...
本机已安装 Python3.9.12，如果依赖无法正常安装，建议升级到 Python3.10.5
numpy 未安装
Pillow 未安装
matplotlib 未安装
pyecharts 未安装
tqdm 未安装
lxml 未安装
beautifulsoup4 未安装
是否安装依赖？(y/n)n

环境安装完成!
```